DataFed Integration
===================

Quick Upload
------------
.. autofunction:: nufeb_tools.storage.upload_datafed


Verify Connection
-----------------
.. autofunction:: nufeb_tools.utils.verify_datafed_connection


Create Collection
-----------------
.. autofunction:: nufeb_tools.utils.create_datafed_collection


Upload Data
-----------
.. autofunction:: nufeb_tools.utils.upload_datafed

Get Data
--------
.. autofunction:: nufeb_tools.utils.get_data.get_datafed_data
